@@ -1,8 +1,8 @@
 from pipetools.utils import foreach
 
-__version__ = VERSION = 0, 2, 0
+__version__ = VERSION = 0, 2, 1
 
 __versionstr__ = VERSION > foreach(str) | '.'.join
 
-from pipetools.main import pipe, X, maybe, xcurry
+from pipetools.main import pipe, X, maybe, xpartial
 from pipetools.utils import *
